#include "test.h"


class test_impl : virtual public test
{
public:

  test_impl() : DCOPObject("test") {};

  void noArg();

  void asyncNoArg();

  void oneArg(bool b);

  bool returnFalse();

  bool returnTrue();

  short shortArg(short in);

  int intArg(int in);

  long longArg(long in);

  float floatArg(float in);
  
  double doubleArg(double in);

  QString stringArg(QString in);

  QCString cstringArg(QCString in);

  QStringList stringListArg(QStringList in);

  DCOPRef DCOPRefArg(DCOPRef in);

};
